@@ -301,9 +301,13 @@ class FieldConverterMixin:
             if self.openapi_version.major < 3:
                 attributes["x-nullable"] = True
             elif self.openapi_version.minor < 1:
-                attributes["nullable"] = True
                 if "$ref" in ret:
-                    attributes["allOf"] = [{"$ref": ret.pop("$ref")}]
+                    attributes["anyOf"] = [
+                        {"type": "object", "nullable": True},
+                        {"$ref": ret.pop("$ref")},
+                    ]
+                else:
+                    attributes["nullable"] = True
             else:
                 if "$ref" in ret:
                     attributes["anyOf"] = [{"$ref": ret.pop("$ref")}, {"type": "null"}]
@@ -504,6 +508,8 @@ class FieldConverterMixin:
             value_field = field.value_field
             if value_field:
                 ret["additionalProperties"] = self.field2property(value_field)
+            else:
+                ret["additionalProperties"] = {}
         return ret
 
     def timedelta2properties(self, field, **kwargs: typing.Any) -> dict:
@@ -578,9 +584,11 @@ class FieldConverterMixin:
                 ret = {
                     "type": "string",
                     "format": None,
-                    "pattern": field.metadata["pattern"]
-                    if field.metadata.get("pattern")
-                    else None,
+                    "pattern": (
+                        field.metadata["pattern"]
+                        if field.metadata.get("pattern")
+                        else None
+                    ),
                 }
         return ret
 
